@@ -10,6 +10,27 @@ from pprint import pprint, pformat
 from . import cfg
 
 
+def RP_to_cfg(key, prefix="", overwrite=True, mappedvalues=[]):
+    if hasattr(key, "items"):
+        for k, v in key.items():
+            # remove both * and + that can be present for special IBOX usage
+            key_name = f"{prefix}{k}".translate("".maketrans({"*": None, "+": None}))
+            try:
+                getattr(cfg, key_name)
+                exist = True
+            except Exception:
+                exist = False
+            if not exist or overwrite:
+                setattr(cfg, key_name, v)
+                if key_name not in mappedvalues:
+                    cfg.fixedvalues[key_name] = v
+            # recursively traverse dict
+            # keys name are the concatenation of traversed dict keys
+            if isinstance(v, dict):
+                for j, w in v.items():
+                    RP_to_cfg({f"{k}{j}": w}, prefix, overwrite)
+
+
 def build_RP():
     LD_INCLUDED = []
     LD_EXCLUDED = []
@@ -96,16 +117,14 @@ def build_RP():
                         self._root_base_ext,
                         self._root_brand_ext,
                     ]:
+                        if "/" not in filename and self.root_current_suffix:
+                            # for file in subfolder that include file without a path
+                            # search only in current subfolder
+                            path = os.path.join(path, self.root_current_suffix)
+
                         contents = self.extractFile(filename, path)
                         if contents:
                             result.append(contents)
-                        if self.root_current_suffix:
-                            # search in subfolder too
-                            contents = self.extractFile(
-                                filename, os.path.join(path, self.root_current_suffix)
-                            )
-                            if contents:
-                                result.append(contents)
                 return result
             else:
                 print("Error:: unrecognised node type in !include statement")
@@ -219,6 +238,9 @@ def build_RP():
             elif isinstance(RP.get(key), str) and RP[key] == "IBOX_SKIP_FUNC":
                 # if key need to be skipped using IBOX_SKIP_FUNC avoid overwriting it
                 pass
+            elif key in cfg.MERGE_RP_KEEP_AS_LIST and isinstance(data, list):
+                # this keys need to stay as a list of dicts
+                RP[key] = data
             else:
                 RP[key] = _recurse(data)
 
@@ -250,27 +272,6 @@ def build_RP():
         except IOError:
             return {}
 
-    def RP_to_cfg(key, prefix="", overwrite=True):
-        if hasattr(key, "items"):
-            for k, v in key.items():
-                # remove both * and + that can be present for special IBOX usage
-                key_name = f"{prefix}{k}".translate(
-                    "".maketrans({"*": None, "+": None})
-                )
-                try:
-                    getattr(cfg, key_name)
-                    exist = True
-                except Exception:
-                    exist = False
-                if not exist or overwrite:
-                    setattr(cfg, key_name, v)
-                    cfg.fixedvalues[key_name] = v
-                # recursively traverse dict
-                # keys name are the concatenation of traversed dict keys
-                if isinstance(v, dict):
-                    for j, w in v.items():
-                        RP_to_cfg({f"{k}{j}": w}, prefix, overwrite)
-
     def inject_ibox_base(RP):
         base_key = "IBOX_BASE"
         for main_key in list(RP.keys()):
