@@ -83,15 +83,9 @@ PARAMETERS_SKIP_OVERRIDE_CONDITION = (
     "VPCName",
 )
 
-EVAL_FUNCTIONS_IN_CFG = (
-    "cfg.",
-    "get_expvalue(",
+EVAL_TROPO_FUNCTIONS_IN_CFG = (
     "Sub(",
     "Ref(",
-    "get_subvalue(",
-    "get_endvalue(",
-    "get_resvalue(",
-    "get_condition(",
     "GetAtt(",
     "Split(",
     "Select(",
@@ -103,14 +97,26 @@ EVAL_FUNCTIONS_IN_CFG = (
     "Equals(",
     "Not(",
     "GetAZs(",
+    "Tags(",
+)
+
+EVAL_PYTHON_FUNCTIONS_IN_CFG = (
+    "cfg.",
+    "get_expvalue(",
+    "get_subvalue(",
+    "get_endvalue(",
+    "get_resvalue(",
+    "get_condition(",
     "dict(",
     "eval(",
-    "Tags(",
     "str(",
     "list(",
+    "getattr(",
     "SG_SecurityGroups",
 )
 
+EVAL_FUNCTIONS_IN_CFG = EVAL_PYTHON_FUNCTIONS_IN_CFG + EVAL_TROPO_FUNCTIONS_IN_CFG
+
 CLF_PATH_PATTERN_REPLACEMENT = {
     "/": "SLASH",
     "*": "STAR",
@@ -120,6 +126,8 @@ CLF_PATH_PATTERN_REPLACEMENT = {
     "_": "USCORE",
 }
 
+MERGE_RP_KEEP_AS_LIST = ("IBOX_LINKED_OBJ",)
+
 INSTANCE_SIZES = [
     "nano",
     "micro",
@@ -260,15 +268,26 @@ CFG_TO_FUNC = {
         "dep": ["LoadBalancer"],
     },
     "ApiGatewayAccount": {"module": "joker", "func": ("apigateway", "Account")},
-    "ApiGatewayApiKey": {"module": "apigateway", "func": "AGW_ApiKeys"},
+    "ApiGatewayApiKey": {"module": "joker", "func": ("apigateway", "ApiKey")},
     "ApiGatewayBasePathMapping": {
         "module": "joker",
         "func": ("apigateway", "BasePathMapping"),
     },
-    "ApiGatewayDomainName": {"module": "apigateway", "func": "AGW_DomainName"},
-    "ApiGatewayRestApi": {"module": "apigateway", "func": "AGW_RestApi"},
-    "ApiGatewayStage": {"module": "apigateway", "func": "AGW_Stages"},
-    "ApiGatewayUsagePlan": {"module": "apigateway", "func": "AGW_UsagePlans"},
+    "ApiGatewayDeployment": {
+        "module": "joker",
+        "func": ("apigateway", "Deployment"),
+        "dep": ["ApiGatewayStage"],
+    },
+    "ApiGatewayDomainName": {"module": "joker", "func": ("apigateway", "DomainName")},
+    "ApiGatewayMethod": {"module": "joker", "func": ("apigateway", "Method")},
+    "ApiGatewayRestApi": {"module": "joker", "func": ("apigateway", "RestApi")},
+    "ApiGatewayResource": {"module": "joker", "func": ("apigateway", "Resource")},
+    "ApiGatewayStage": {"module": "joker", "func": ("apigateway", "Stage")},
+    "ApiGatewayUsagePlan": {"module": "joker", "func": ("apigateway", "UsagePlan")},
+    "ApiGatewayUsagePlanKey": {
+        "module": "joker",
+        "func": ("apigateway", "UsagePlanKey"),
+    },
     "ApplicationAutoScalingScalingPolicy": {
         "module": "autoscaling",
         "func": "AS_ScalingPolicies",
@@ -288,7 +307,11 @@ CFG_TO_FUNC = {
     "CloudFrontDistribution": {
         "module": "cloudfront",
         "func": "CF_CloudFront",
-        "dep": ["LoadBalancer"],
+        "dep": ["LoadBalancer", "CloudFrontLambdaFunctionAssociation"],
+    },
+    "CloudFrontLambdaFunctionAssociation": {
+        "module": "joker",
+        "func": ("cloudfront", "LambdaFunctionAssociation"),
     },
     "CloudFrontOriginAccessIdentity": {
         "module": "joker",
@@ -299,8 +322,6 @@ CFG_TO_FUNC = {
         "func": ("cloudfront", "OriginRequestPolicy"),
     },
     "CodeDeployApp": {"module": "joker", "func": ("codedeploy", "Application")},
-    "DBInstance": {"module": "rds", "func": "RDS_DB"},
-    "DBSubnetGroup": {"module": "joker", "func": ("rds", "DBSubnetGroup")},
     "DynamoDBTable": {"module": "joker", "func": ("dynamodb", "Table")},
     "EC2EIP": {"module": "joker", "func": ("ec2", "EIP")},
     "EC2InternetGateway": {"module": "joker", "func": ("ec2", "InternetGateway")},
@@ -339,14 +360,20 @@ CFG_TO_FUNC = {
         "func": "EVE_EventRules",
         "dep": ["SecurityGroups"],
     },
-    "HostedZone": {"module": "route53", "func": "R53_HostedZones"},
     "IAMGroup": {"module": "iam", "func": "IAM_Groups"},
-    "IAMPolicy": {"module": "iam", "func": "IAM_Policies"},
+    "IAMInstanceProfile": {"module": "joker", "func": ("iam", "InstanceProfile")},
+    "IAMManagedPolicy": {"module": "joker", "func": ("iam", "ManagedPolicy")},
+    "IAMPolicy": {"module": "joker", "func": ("iam", "PolicyType")},
+    "IAMRole": {
+        "module": "joker",
+        "func": ("iam", "Role"),
+        "dep": ["Lambda", "Bucket"],
+    },
     "IAMUser": {"module": "iam", "func": "IAM_Users"},
     "IAMUserToGroupAddition": {"module": "iam", "func": "IAM_UserToGroupAdditions"},
     "KMSAlias": {"module": "joker", "func": ("kms", "Alias")},
     "KMSKey": {"module": "joker", "func": ("kms", "Key")},
-    "Lambda": {"module": "lambdas", "func": "LBD_Lambdas"},
+    "Lambda": {"module": "joker", "func": ("awslambda", "Function")},
     "LambdaEventInvokeConfig": {
         "module": "joker",
         "func": ("awslambda", "EventInvokeConfig"),
@@ -355,15 +382,24 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("awslambda", "EventSourceMapping"),
     },
-    "LambdaFunctionAssociation": {
+    "LambdaLayerVersion": {"module": "joker", "func": ("awslambda", "LayerVersion")},
+    "LambdaLayerVersionPermission": {
         "module": "joker",
-        "func": ("cloudfront", "LambdaFunctionAssociation"),
-        "dep": ["CloudFrontDistribution"],
+        "func": ("awslambda", "LayerVersionPermission"),
+        "dep": ["LambdaLayerVersion"],
+    },
+    "LambdaPermission": {
+        "module": "joker",
+        "func": ("awslambda", "Permission"),
+        "dep": ["SNSSubscription", "Lambda", "EventsRule"],
+    },
+    "LambdaVersion": {
+        "module": "joker",
+        "func": ("awslambda", "Version"),
+        "dep": ["Lambda"],
     },
-    "LambdaLayerVersion": {"module": "lambdas", "func": "LBD_LayerVersions"},
-    "LambdaPermission": {"module": "joker", "func": ("awslambda", "Permission")},
     "LoadBalancer": {
-        "module": "loadbalancing",
+        "module": "elasticloadbalancing",
         "func": "LB_ElasticLoadBalancing",
     },
     "LogsLogGroup": {"module": "joker", "func": ("logs", "LogGroup")},
@@ -372,15 +408,21 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("applicationautoscaling", "ScalableTarget"),
     },
-    "R53RecordSet": {"module": "joker", "func": ("route53", "RecordSetType")},
+    "RDSDBInstance": {"module": "rds", "func": "RDS_DB"},
+    "RDSDBSubnetGroup": {"module": "joker", "func": ("rds", "DBSubnetGroup")},
     "Repository": {"module": "ecr", "func": "ECR_Repositories"},
-    "Role": {"module": "iam", "func": "IAM_Roles"},
-    "SecurityGroup": {"module": "securitygroup", "func": "SG_SecurityGroup"},
+    "Route53HostedZone": {"module": "joker", "func": ("route53", "HostedZone")},
+    "Route53RecordSet": {
+        "module": "joker",
+        "func": ("route53", "RecordSetType"),
+        "dep": ["ApiGatewayDomainName", "DBInstance", "EFSFileSystem", "LoadBalancer"],
+    },
+    "SecurityGroup": {"module": "ec2", "func": "SG_SecurityGroup"},
     "SecurityGroupIngress": {
-        "module": "securitygroup",
+        "module": "ec2",
         "func": "SG_SecurityGroupIngresses",
     },
-    "SecurityGroups": {"module": "securitygroup", "func": "SG_SecurityGroups"},
+    "SecurityGroups": {"module": "ec2", "func": "SG_SecurityGroups"},
     "Service": {
         "module": "ecs",
         "func": "ECS_Service",
@@ -395,8 +437,14 @@ CFG_TO_FUNC = {
         "func": ("servicediscovery", "Service"),
     },
     "SQSQueue": {"module": "joker", "func": ("sqs", "Queue")},
-    "SNSSubscription": {"module": "sns", "func": "SNS_Subscriptions"},
+    "SQSQueuePolicy": {
+        "module": "joker",
+        "func": ("sqs", "QueuePolicy"),
+        "dep": ["SNSSubscription"],
+    },
+    "SNSSubscription": {"module": "joker", "func": ("sns", "SubscriptionResource")},
     "SNSTopic": {"module": "joker", "func": ("sns", "Topic")},
+    "SSMParameter": {"module": "joker", "func": ("ssm", "Parameter")},
     "TaskDefinition": {"module": "ecs", "func": "ECS_TaskDefinition"},
     "WafByteMatchSet": {
         "module": "waf",
