@@ -11,9 +11,8 @@ from .shared import (
     add_obj,
     get_dictvalue,
 )
-from .iam import IAMRoleBucketReplica, IAMPolicyBucketReplica, IAMPolicyStatement
+from .iam import IAMPolicyBucketReplica, IAMPolicyStatement
 from .cloudfront import CFOriginAccessIdentity
-from .lambdas import LambdaPermissionS3
 
 
 class S3Bucket(s3.Bucket):
@@ -285,8 +284,6 @@ def S3_Buckets(key):
         )
 
         # resources
-        BucketPolicyStatement = []
-
         r_Bucket = S3Bucket(resname, key=v)
 
         Replica_Rules = []
@@ -294,11 +291,9 @@ def S3_Buckets(key):
             replica_name = f"{resname}ReplicationConfigurationRules{m}"
 
             # parameters
-            p_replicabucket = Parameter(f"{replica_name}DestinationBucket")
-            p_replicabucket.Description = (
-                "Replica Destination Bucket "
-                "- empty for default based on "
-                "Env/Roles/Region"
+            p_replicabucket = Parameter(
+                f"{replica_name}DestinationBucket",
+                Description="Replica Destination Bucket - empty for default based on Env/Roles/Region",
             )
             add_obj(p_replicabucket)
 
@@ -312,10 +307,9 @@ def S3_Buckets(key):
             )
 
             # resources
-            rule = s3.ReplicationConfigurationRules(replica_name)
+            rule = s3.ReplicationConfigurationRules(replica_name, Status="Enabled")
             auto_get_props(rule)
 
-            rule.Status = "Enabled"
             Replica_Rules.append(
                 If(f"{replica_name}DestinationBucket", rule, Ref("AWS::NoValue"))
             )
@@ -344,9 +338,14 @@ def S3_Buckets(key):
                 )
             )
 
-        r_Policy = S3BucketPolicy(f"BucketPolicy{name}", key=v)
-        r_Policy.Condition = resname
-        r_Policy.Bucket = Ref(resname)
+        BucketPolicyStatement = []
+
+        r_Policy = S3BucketPolicy(
+            f"BucketPolicy{name}",
+            key=v,
+            Condition=resname,
+            Bucket=Ref(resname),
+        )
         r_Policy.PolicyDocument["Statement"] = BucketPolicyStatement
 
         # At least one statement must be always present,
@@ -357,8 +356,6 @@ def S3_Buckets(key):
             S3BucketPolicyStatementReplica(resname, PolicyStatementReplicaResources)
         )
 
-        r_Role = IAMRoleBucketReplica(f"Role{resname}Replica")
-
         BucketPolicyStatement.extend(
             S3BucketPolicyStatementRead(resname, PolicyReadPrincipal)
         )
@@ -375,38 +372,6 @@ def S3_Buckets(key):
             key=v["Replication"]["ConfigurationRules"],
         )
 
-        try:
-            lbd_confs = v["NotificationConfiguration"]["LambdaConfigurations"]
-        except Exception:
-            pass
-        else:
-            for lbd_n, lbd_v in lbd_confs.items():
-                try:
-                    lambda_arn = eval(lbd_v["Function"])
-
-                    if "Fn::GetAtt" in lambda_arn.data:
-                        lambda_name = lambda_arn.data["Fn::GetAtt"][0]
-                        permname = "%s%s" % (
-                            lambda_name.replace("Lambda", "LambdaPermission"),
-                            resname,
-                        )
-                except Exception:
-                    lambda_arn = lbd_v["Function"]
-                    permname = f"LambdaPermission{resname}"
-
-                r_LambdaPermission = LambdaPermissionS3(
-                    permname, key=lambda_arn, source=bucket_name
-                )
-
-                try:
-                    r_LambdaPermission.Condition = getattr(
-                        cfg, f"{lambda_name}Condition"
-                    )
-                except Exception:
-                    pass
-
-                add_obj(r_LambdaPermission)
-
         try:
             bucket_policies = getattr(cfg, "BucketPolicy")
         except Exception:
@@ -489,24 +454,19 @@ def S3_Buckets(key):
             )
 
             r_OriginAccessIdentity = CFOriginAccessIdentity(
-                identityresname, comment=identityname
+                identityresname, comment=identityname, Condition=identitycondname
             )
-            r_OriginAccessIdentity.Condition = identitycondname
 
-            add_obj(
-                [
-                    r_OriginAccessIdentity,
-                ]
-            )
+            add_obj(r_OriginAccessIdentity)
 
             # outputs
-            o_OriginAccessIdentity = Output(identityresname)
-            o_OriginAccessIdentity.Value = Ref(identityresname)
-            o_OriginAccessIdentity.Condition = identitycondname
+            o_OriginAccessIdentity = Output(
+                identityresname, Value=Ref(identityresname), Condition=identitycondname
+            )
 
             add_obj(o_OriginAccessIdentity)
 
-        add_obj([r_Bucket, r_Policy, r_IAMPolicyReplica, r_Role])
+        add_obj([r_Bucket, r_Policy, r_IAMPolicyReplica])
 
         # outputs
         o_Bucket = Output(resname)
