@@ -3,6 +3,7 @@ import troposphere.ssm as ssm
 import troposphere.policies as pol
 
 from .common import *
+from .RP import RP_to_cfg
 
 IBOX_SPECIAL_KEYS = (
     "IBOX_RESNAME",
@@ -10,27 +11,34 @@ IBOX_SPECIAL_KEYS = (
     "IBOX_REMAPNAME",
     "IBOX_INDEXNAME",
     "IBOX_PROPNAME",
+    "IBOX_LINKED_OBJ_NAME",
+    "IBOX_LINKED_OBJ_INDEX",
+    "IBOX_LINKED_OBJ_FOR",
 )
 
 
-# S - PARAMETERS #
-class SSMParameter(ssm.Parameter):
-    Type = "String"
+class IBOX_Custom_Obj(AWSProperty):
+    props: PropsDictType = {
+        "Value": (str, True),
+    }
 
 
 class Parameter(Parameter):
     def __init__(self, title, **kwargs):
         super().__init__(title, **kwargs)
-        self.Type = "String"
-        self.Default = ""
+        if "Type" not in kwargs:
+            self.Type = "String"
+        if "Default" not in kwargs:
+            self.Default = ""
 
         # Create SSM Parameter for EnvAppXVersion Params to have history of application versions
         if title.startswith("EnvApp") and title.endswith("Version"):
             add_obj(
                 [
                     get_condition(title, "not_equals", "", nomap=True),
-                    SSMParameter(
+                    ssm.Parameter(
                         f"SSMParameter{title}",
+                        Type="String",
                         Condition=title,
                         Name=Sub(
                             "/EnvAppVersions/${EnvRole}/${AWS::StackName}/%s" % title
@@ -41,9 +49,6 @@ class Parameter(Parameter):
             )
 
 
-# E - PARAMETERS #
-
-
 def stack_add_res():
     for n, v in cfg.Parameters.items():
         # Automatically create override conditions for parameters
@@ -107,7 +112,7 @@ def add_obj(obj):
             if hasattr(obj, "Condition"):
                 # Condition is not supported on Resource properties, but use it
                 # to wrap obj in an If Condition - needed for LambdaFunctionAssociation
-                cond_name = obj.Condition
+                cond_name = parse_ibox_key(obj.Condition)
                 del obj.properties["Condition"]
                 obj = If(cond_name, obj, Ref("AWS::NoValue"))
 
@@ -139,7 +144,7 @@ def add_objoutput(res):
             # i do this only if Value is not a string
             # i need Condition only if using Ref for getting the resource
             try:
-                res.Condition
+                condition = res.Condition
             except Exception:
                 try:
                     cond = iboxprops[f"{mapname}Condition"][0].Condition
@@ -147,6 +152,10 @@ def add_objoutput(res):
                     pass
                 else:
                     res.Condition = cond
+            else:
+                # Use a fake Condition wih value None in cfg to avoid creating a condition
+                if condition == "None":
+                    del res.properties["Condition"]
 
         del res.properties["IBOX_PROPS"]
 
@@ -316,12 +325,17 @@ def get_dictvalue(key):
         value = [get_dictvalue(k) for k in key]
     elif isinstance(key, dict) and "IBOX_LIST" in key:
         # Usefull for KMS policy and other generic dict properties
-        del key["IBOX_LIST"]
-        value = [{i: get_dictvalue(k) for i, k in key.items()}]
+        value = []
+        for i, k in key.items():
+            if i == "IBOX_LIST":
+                continue
+            value.append({j: get_dictvalue(w) for j, w in k.items()})
     elif isinstance(key, dict):
         value = {i: get_dictvalue(k) for i, k in key.items()}
-    else:
+    elif isinstance(key, str):
         value = eval(key) if key.startswith(cfg.EVAL_FUNCTIONS_IN_CFG) else key
+    else:
+        value = key
 
     return value
 
@@ -414,7 +428,7 @@ def get_condition(
 
 
 def import_user_data(name):
-    TK_IN_UDATA = "IBOX_CODE_IN_USER_DATA"
+    TK_IN_UDATA = "_IBOX_CODE_"
 
     udata_file = os.path.join(os.getcwd(), f"lib/user-data/{name}.sh")
     if not os.path.exists(udata_file):
@@ -509,15 +523,30 @@ def import_lambda(name):
 
 
 def auto_get_props(
-    obj, mapname=None, key=None, rootdict=None, indexname="", remapname=None
+    obj,
+    mapname="",
+    key=None,
+    rootdict=None,
+    indexname="",
+    remapname="",
+    linked_obj_name="",
+    linked_obj_index="",
 ):
     # IBOX_RESNAME can be used in yaml and resolved inside get_endvalue
     global IBOX_RESNAME, IBOX_MAPNAME, IBOX_INDEXNAME, IBOX_REMAPNAME, IBOX_PROPNAME
+    global IBOX_LINKED_OBJ_NAME, IBOX_LINKED_OBJ_INDEX
     IBOX_RESNAME = obj.title
-    IBOX_MAPNAME = mapname
-    IBOX_REMAPNAME = remapname
-    IBOX_INDEXNAME = indexname
     IBOX_PROPNAME = ""
+    if not "IBOX_MAPNAME" in globals() or mapname:
+        IBOX_MAPNAME = mapname
+    if not "IBOX_REMAPNAME" in globals() or remapname:
+        IBOX_REMAPNAME = remapname
+    if not "IBOX_INDEXNAME" in globals() or indexname:
+        IBOX_INDEXNAME = indexname
+    if not "IBOX_LINKED_OBJ_NAME" in globals() or linked_obj_name:
+        IBOX_LINKED_OBJ_NAME = linked_obj_name
+    if not "IBOX_LINKED_OBJ_INDEX" in globals() or linked_obj_index:
+        IBOX_LINKED_OBJ_INDEX = linked_obj_index
 
     # create a dict where i will put all property with a flat hierarchy
     # with the name equals to the mapname and the relative value.
@@ -653,6 +682,9 @@ def auto_get_props(
             isinstance(prop_class, tuple)
             and isinstance(prop_class[0], type)
             and prop_class[0].__name__ == "dict"
+        ) or (
+            callable(prop_class)
+            and prop_class.__name__ in ["policytypes", "validate_variables_name"]
         ):
             return get_dictvalue(key[obj_propname])
 
@@ -682,7 +714,7 @@ def auto_get_props(
             def _output(k):
                 for n, v in k.items():
                     n = parse_ibox_key(n)
-                    if not eval(v.get("IBOX_CODE_IF", "True")):
+                    if not eval(v.get("IBOX_ENABLED_IF", "True")):
                         continue
                     output = Output(n)
                     _populate(output, rootdict=v)
@@ -723,6 +755,104 @@ def auto_get_props(
                 output = {"IBOX_OUTPUT": {f"{mapname}{name}": output_base}}
                 _try_PCO_in_obj(output)
 
+        def _process_ibox_auto_pco_key(propname):
+            ibox_auto_po = f"{propname}.IBOX_AUTO_PO"
+            ibox_auto_p = f"{propname}.IBOX_AUTO_P"
+            ibox_pco = f"{propname}.IBOX_PCO"
+
+            # IBOX_AUTO_PO
+            for n in [ibox_auto_po, ibox_auto_p]:
+                if n in key:
+                    # Automatically create parameter
+                    _auto_PO(propname, key[n], "p")
+
+            # IBOX_PCO
+            if ibox_pco in key:
+                # If there is a key ending with {propname}.IBOX_PCO process it
+                _try_PCO_in_obj(key[ibox_pco])
+
+        def _proc_custom_obj(name, key_value, mapname):
+            values = []
+            base_rootdict = getattr(cfg, f"{name}IBOX_CUSTOM_OBJ")
+            if isinstance(key_value, dict):
+                my_iter = iter(key_value.items())
+                is_dict = True
+            else:
+                my_iter = enumerate(key_value)
+                is_dict = False
+
+            for n, v in my_iter:
+                rootdict = {"Value": v}
+                rootdict.update(base_rootdict)
+                obj = IBOX_Custom_Obj(n if is_dict else v)
+                auto_get_props(obj, rootdict=rootdict)
+                value = getattr(obj, "Value")
+                if v == "IBOX_IFCONDVALUE":
+                    condname = f"{mapname}{n}"
+                    add_obj(get_condition(condname, "not_equals", "IBOX_IFCONDVALUE"))
+                    values.append(If(condname, value, Ref("AWS::NoValue")))
+                else:
+                    values.append(value)
+            return values
+
+        def _linked_obj(linked_obj_data):
+            # need to parse them here to have the right values
+            lo_name = parse_ibox_key(linked_obj_data.get("Name", IBOX_RESNAME))
+            lo_key = parse_ibox_key(linked_obj_data.get("Key", ""))
+            lo_type = parse_ibox_key(linked_obj_data.get("Type", ""))
+            # this way even if without key "For", for cycle will run at least one time
+            lo_for_cycle = linked_obj_data.get("For", [""])
+
+            louc_cfg = {}
+            for lo_for_index in lo_for_cycle:
+                # need to copy it because it's updated
+                lo_conf = copy.deepcopy(linked_obj_data.get("Conf", {}))
+                lo_conf["IBOX_ENABLED"] = True
+                # for all lo_conf entries, if their value is a string parse it using parse_ibox_key
+                for loc_entry_key, loc_entry_value in lo_conf.items():
+                    lo_conf[loc_entry_key] = parse_ibox_key(loc_entry_value)
+                    lo_conf[loc_entry_key] = parse_ibox_key(
+                        loc_entry_value, conf={"IBOX_LINKED_OBJ_FOR": lo_for_index}
+                    )
+
+                linked_obj_key_name = f"{lo_key}{lo_type}{lo_for_index}"
+                target_name = f"{lo_name}{lo_for_index}"
+
+                # get existing object
+                if f"{lo_key}{target_name}" == linked_obj_key_name:
+                    # source and target are the same, so update the object in place
+                    linked_obj = getattr(cfg, linked_obj_key_name)
+                else:
+                    # copy it, first search for the full name including for index
+                    linked_obj = copy.deepcopy(
+                        getattr(
+                            cfg,
+                            linked_obj_key_name,
+                            getattr(cfg, f"{lo_key}{lo_type}", None),
+                        )
+                    )
+
+                # update it with config from IBOX_LINKED_OBJ Conf
+                linked_obj.update(lo_conf)
+
+                lo_resname = lo_conf.get("IBOX_RESNAME", f"{lo_key}{lo_name}")
+                linked_obj["IBOX_RESNAME"] = f"{lo_resname}{lo_for_index}"
+
+                condition = key.get("Condition", getattr(obj, "Condition", None))
+                if condition and not "Condition" in linked_obj:
+                    # automatically add Condition if source obj have it and target not
+                    linked_obj["Condition"] = parse_ibox_key(condition)
+
+                # assign to louc_cfg lo_key
+                louc_cfg[target_name] = linked_obj
+
+            if cfg.debug:
+                pprint(louc_cfg)
+            # update cfg and fixedvalues, need to do it this way to avoid overwriting the lo_key and removing all objects
+            RP_to_cfg(louc_cfg, prefix=lo_key, mappedvalues=cfg.mappedvalues)
+            # finally update cfg object base key with configuration including mutiple objects
+            getattr(cfg, lo_key).update(louc_cfg)
+
         # Allowed object properties
         props = list(vars(obj)["propnames"])
         props.extend(vars(obj)["attributes"])
@@ -730,37 +860,54 @@ def auto_get_props(
         # Parameters, Conditions, Outpus in yaml cfg
         _try_PCO_in_obj(key)
 
+        # For linked resources as r53recordset, update their keys conf.
+        # This way they can be enabled or their name can be changed, or so on...
+        ibox_linked_obj = key.get("IBOX_LINKED_OBJ")
+        if ibox_linked_obj:
+            # bad hack to use a dict for ibox_linked_obj, so that i can modify it if needed using the index name
+            # but avoid intercepting the "normal" conf that is a dict too (a key named Type must not exist)
+            if isinstance(ibox_linked_obj, dict) and "Type" not in ibox_linked_obj:
+                for linked_obj in ibox_linked_obj.values():
+                    _linked_obj(linked_obj)
+            else:
+                _linked_obj(ibox_linked_obj)
+
+        # iterate over both obj props and key - using key order
         for propname in dict(
             list(key.items()) + list(dict.fromkeys(props, None).items())
         ).keys():
-            # iterate over both obj props and key - using key order
+            if key.get(propname) == "IBOX_SKIP":
+                continue
 
-            # IBOX_AUTO_PO
-            for n in [f"{propname}.IBOX_AUTO_PO", f"{propname}.IBOX_AUTO_P"]:
-                if n in key:
-                    # Automatically create parameter
-                    _auto_PO(propname, key[n], "p")
-
-            # IBOX_PCO
-            ibox_pco = f"{propname}.IBOX_PCO"
-            if ibox_pco in key:
-                # If there is a key ending with {prop}.IBOX_PCO process it
-                _try_PCO_in_obj(key[ibox_pco])
+            # IBOX KEY TO LOOK FOR
+            ibox_auto_po = f"{propname}.IBOX_AUTO_PO"
+            ibox_code = f"{propname}.IBOX_CODE"
+            ibox_code_key = f"{propname}.IBOX_CODE_KEY"
+            ibox_custom_obj = f"{propname}.IBOX_CUSTOM_OBJ"
 
             # IBOX_CODE
-            ibox_code = f"{propname}.IBOX_CODE"
-            if ibox_code in key:
-                # If there is a key ending with {prop}.IBOX_CODE
-                # eval it and use it as prop value.
-                # Usefull if a str value need to be processed by a code.
-                # (like in autoscaling-scheduledactions.yml)
+            if ibox_code in key and propname in props:
+                # If there is a key ending with {prop}.IBOX_CODE  eval it and use it as prop value.
+                # First process IBOX_AUTO_PO and IBOX_PCO keys
+                _process_ibox_auto_pco_key(propname)
                 value = eval(key[ibox_code])
             elif propname in key and propname in props:
                 # there is match between obj prop and a dict key
                 key_value = key[propname]
 
+                # Process IBOX_AUTO_PO and IBOX_PCO keys
+                _process_ibox_auto_pco_key(propname)
+
+                # IBOX_CODE_KEY - like IBOX_CODE but only if propname is in key too
+                if ibox_code_key in key:
+                    value = eval(key[ibox_code_key])
                 # set value
-                if isinstance(key_value, dict):
+                elif isinstance(key_value, (list, dict)) and ibox_custom_obj in key:
+                    # to process a list like a custom obj
+                    value = _proc_custom_obj(
+                        key[ibox_custom_obj], key_value, f"{mapname}{propname}"
+                    )
+                elif isinstance(key_value, dict):
                     # key value is a dict, get populated object
                     value = _get_obj(obj, key, propname, mapname)
                 elif isinstance(key_value, str) and key_value.startswith(
@@ -816,9 +963,12 @@ def auto_get_props(
                 IBOX_PROPS[f"{mapname}{propname}"] = (obj, propname)
 
                 # Automatically create output
-                for n in [f"{propname}.IBOX_AUTO_PO", f"{propname}.IBOX_AUTO_O"]:
-                    if n in key:
-                        _auto_PO(propname, key[n], "o", value)
+                if ibox_auto_po in key:
+                    ibox_auto_po_value = key[ibox_auto_po]
+                    if "Description" in ibox_auto_po_value:
+                        # avoid parsing Parameter Descrption as output one
+                        del ibox_auto_po_value["Description"]
+                    _auto_PO(propname, ibox_auto_po_value, "o", value)
 
         # title override
         try:
@@ -893,10 +1043,17 @@ def clf_compute_order(pattern):
     return base_ord
 
 
-def parse_ibox_key(value):
+def parse_ibox_key(value, conf={}):
+    if not isinstance(value, str):
+        return value
+    if value.startswith(cfg.EVAL_PYTHON_FUNCTIONS_IN_CFG):
+        return eval(value)
     for key in IBOX_SPECIAL_KEYS:
         if key in value:
-            value = value.replace(key, globals().get(key, ""))
+            if key in conf:
+                value = value.replace(key, conf[key])
+            else:
+                value = value.replace(key, globals().get(key, ""))
     value = value.replace("_", IBOX_RESNAME)
     value = value.replace(".", "")
 
